@@ -672,8 +672,12 @@ def _process_session_data(irmc_info, operation, session_id,
                 if operation == 'CONFIG_RAID':
                     return result
 
-                elcm_profile_delete(irmc_info=irmc_info,
-                                    profile_name=PROFILE_BIOS_CONFIG)
+                # FIXME: Currently, creating a profile will restart the
+                # machine, which will cause an error during IPI installation,
+                # so temporarily comment out the operation of deleting the
+                # profile.
+                # elcm_profile_delete(irmc_info=irmc_info,
+                #                    profile_name=PROFILE_BIOS_CONFIG)
 
             except scci.SCCIError as e:
                 result['warning'] = e
@@ -712,31 +716,36 @@ def backup_bios_config(irmc_info):
             'warning': <warning message if there is>
         }
     """
+    result = {}
+
     # 1. Make sure there is no BiosConfig profile in the store
     try:
         # Get the profile first, if not found, then an exception
         # will be raised.
-        elcm_profile_get(irmc_info=irmc_info,
-                         profile_name=PROFILE_BIOS_CONFIG)
+        result['bios_config'] = elcm_profile_get(
+            irmc_info=irmc_info,
+            profile_name=PROFILE_BIOS_CONFIG)
+        # FIXME: Currently, creating a profile will restart the machine,
+        # which will cause an error during IPI installation,
+        # so temporarily comment out the operation of deleting the profile.
         # Profile found, delete it
-        elcm_profile_delete(irmc_info=irmc_info,
-                            profile_name=PROFILE_BIOS_CONFIG)
+        # elcm_profile_delete(irmc_info=irmc_info,
+        #                    profile_name=PROFILE_BIOS_CONFIG)
     except ELCMProfileNotFound:
-        # Ignore this error as it's not an error in this case
-        pass
+        # 2. Send request to create a new profile for BiosConfig
+        session = elcm_profile_create(irmc_info=irmc_info,
+                                      param_path=PARAM_PATH_BIOS_CONFIG)
 
-    # 2. Send request to create a new profile for BiosConfig
-    session = elcm_profile_create(irmc_info=irmc_info,
-                                  param_path=PARAM_PATH_BIOS_CONFIG)
+        # 3. Profile creation is in progress, we monitor the session
+        session_timeout = irmc_info.get('irmc_bios_session_timeout',
+                                        BIOS_CONFIG_SESSION_TIMEOUT)
+        return _process_session_data(
+            irmc_info=irmc_info,
+            operation='BACKUP_BIOS',
+            session_id=session['Session']['Id'],
+            session_timeout=session_timeout)
 
-    # 3. Profile creation is in progress, we monitor the session
-    session_timeout = irmc_info.get('irmc_bios_session_timeout',
-                                    BIOS_CONFIG_SESSION_TIMEOUT)
-    return _process_session_data(
-        irmc_info=irmc_info,
-        operation='BACKUP_BIOS',
-        session_id=session['Session']['Id'],
-        session_timeout=session_timeout)
+    return result
 
 
 def restore_bios_config(irmc_info, bios_config):
@@ -771,18 +780,21 @@ def restore_bios_config(irmc_info, bios_config):
     # 1. Parse the bios config and create the input data
     input_data = _process_bios_config()
 
+    # FIXME: Currently, creating a profile will restart the machine,
+    # which will cause an error during IPI installation,
+    # so temporarily comment out the operation of deleting the profile.
     # 2. Make sure there is no BiosConfig profile in the store
-    try:
-        # Get the profile first, if not found, then an exception
-        # will be raised.
-        elcm_profile_get(irmc_info=irmc_info,
-                         profile_name=PROFILE_BIOS_CONFIG)
-        # Profile found, delete it
-        elcm_profile_delete(irmc_info=irmc_info,
-                            profile_name=PROFILE_BIOS_CONFIG)
-    except ELCMProfileNotFound:
-        # Ignore this error as it's not an error in this case
-        pass
+    # try:
+    #     Get the profile first, if not found, then an exception
+    #     will be raised.
+    #    elcm_profile_get(irmc_info=irmc_info,
+    #                     profile_name=PROFILE_BIOS_CONFIG)
+    #     Profile found, delete it
+    #    elcm_profile_delete(irmc_info=irmc_info,
+    #                        profile_name=PROFILE_BIOS_CONFIG)
+    # except ELCMProfileNotFound:
+    #     Ignore this error as it's not an error in this case
+    #    pass
 
     # 3. Send a request to apply the param values
     session = elcm_profile_set(irmc_info=irmc_info,
@@ -897,7 +909,7 @@ def _update_raid_input_data(target_raid_config, raid_input):
             array_info['LogicalDrives']['LogicalDrive'].append(
                 {'@Action': 'Create',
                  'RaidLevel': logical_disk['raid_level'],
-                 'InitMode': 'slow'})
+                 'InitMode': 'fast'})
             array_info['LogicalDrives']['LogicalDrive'][i].update({
                 "@Number": i})
 
@@ -919,7 +931,7 @@ def _update_raid_input_data(target_raid_config, raid_input):
                     "ArrayRef": [
                     ]
                 },
-                "InitMode": "slow"
+                "InitMode": "fast"
             }
 
             array_info['Arrays']['Array'].append(arrays)
