@@ -12,19 +12,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import sys
-
+import mock
 import testtools
 
 from scciclient.irmc import scci
 from scciclient.irmc.viom import client as viom_client
 from scciclient.irmc.viom import elcm as viom_elcm
 
-if sys.version_info[0] == 2:
-    import mock
-elif sys.version_info[0] == 3:
-    from unittest import mock
-
 
 class VIOMConfigurationTestCase(testtools.TestCase):
 
