@@ -16,20 +16,15 @@
 Test class for iRMC eLCM functionality.
 """
 
-import sys
 import time
 
+import mock
 import testtools
 
 from scciclient.irmc import elcm
 from scciclient.irmc import scci
 from scciclient.irmc.viom import elcm as viom_elcm
 
-if sys.version_info[0] == 2:
-    import mock
-elif sys.version_info[0] == 3:
-    from unittest import mock
-
 
 class ELCMVIOMClientTestCase(testtools.TestCase):
     """Test for ELCMViomClient."""
